#
# spec file for package eolie
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Filter out unwanted Requires
%global __requires_exclude typelib\\(Unity\\)

Name:           eolie
Version:        0.9.101
Release:        1.16
Summary:        Web browser for GNOME
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Web/Browsers
URL:            https://wiki.gnome.org/Apps/Eolie
Source:         %{name}-%{version}.tar.xz
BuildRequires:  meson >= 0.47
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.35.9
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(pygobject-3.0)
Requires:       python3-cairo
Requires:       python3-dateutil
Requires:       python3-gobject
Recommends:     python3-PyFxA
Recommends:     python3-beautifulsoup4
Recommends:     python3-cryptography
Recommends:     python3-hawkauthlib
Recommends:     python3-pycrypto
Recommends:     python3-requests-hawk
BuildArch:      noarch

%description
Eolie is a Web browser for the GNOME Desktop. It provides:
* Firefox sync support
* Secret password store
* A modern UI

%package -n gnome-shell-search-provider-eolie
Summary:        Eolie Search Provider for GNOME Shell
Group:          Productivity/Networking/Web/Browsers
Requires:       %{name} = %{version}
Requires:       gnome-shell
Supplements:    (%{name} and gnome-shell)

%description -n gnome-shell-search-provider-eolie
This package contains a search provider to enable GNOME Shell to get
search results from the Eolie Web browser.

%lang_package

%prep
%autosetup -p1
# Don't use env interpreter so that the rpm dependency detection works
sed -i 's;/usr/bin/env python3;/usr/bin/python3;' eolie.in search-provider/eolie-sp.in

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_datadir}/metainfo/org.gnome.Eolie.appdata.xml
%{_datadir}/applications/org.gnome.Eolie.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.Eolie.gschema.xml
%{_datadir}/icons/hicolor/*/*/org.gnome.Eolie*
%{_datadir}/%{name}
%{python3_sitelib}/%{name}

%files -n gnome-shell-search-provider-eolie
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/dbus-1/services/org.gnome.Eolie.SearchProvider.service
%{_datadir}/gnome-shell/search-providers/org.gnome.Eolie.SearchProvider.ini
%{_libexecdir}/%{name}-sp

%files lang -f %{name}.lang

%changelog
* Thu Jan  7 2021 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 0.9.101:
  * New settings dialog.
  * Fixed flatpak support.
- Remove eolie-0.9.100-fix-crash-on-ctrl-shift-p.patch: Fixed
  upstream.
* Mon Jan  4 2021 Antoine Belvire <antoine.belvire@opensuse.org>
- Add eolie-0.9.100-fix-crash-on-ctrl-shift-p.patch
  (glgo#World/eolie#381).
* Sat Jan  2 2021 Antoine Belvire <antoine.belvire@opensuse.org>
- Add missing soft dependency on python3-hawkauthlib: For
  authentification to Firefox Sync.
* Sun Oct 25 2020 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 0.9.100:
  * Add an option for a custom Firefox sync server.
  * Allow zooming in reading view.
  * Notifications support.
  * Enable sandboxing.
- Drop soft dependency on git: Not used anymore for ad blocking.
- Replace shebangs which use env interpreter.
* Wed Mar 11 2020 Antoine Belvire <antoine.belvire@opensuse.org>
- Disable Python WebExtension support: It does not build with
  Python 3.8 and it will be replaced in a future release.
* Wed Feb 19 2020 Antoine Belvire <antoine.belvire@opensuse.org>
- Explicitly require pkgconfig(python3) at build time: It's needed
  and it's not pulled by other build dependencies anymore.
* Thu Aug 22 2019 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 0.9.63:
  * Bug fixes.
* Tue May 21 2019 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 0.9.62:
  * Bug fixes.
* Wed May  1 2019 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 0.9.61:
  * Enable two-factor authentification for Firefox sync
    (glgo#World/eolie#336).
  * Disable hardware acceleration to fix rendering of some websites
    (like in Epiphany).
* Thu Mar 21 2019 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 0.9.60:
  * Fix a crash with Wayland.
* Mon Feb 25 2019 antoine.belvire@opensuse.org
- Update to version 0.9.52:
  * Bug fixes.
* Thu Jan 17 2019 antoine.belvire@opensuse.org
- Update to version 0.9.51:
  * Rename ini file for GNOME search provider.
* Wed Jan 16 2019 antoine.belvire@opensuse.org
- Update to version 0.9.50:
  * Fix an issue with navigation.
  * Fix an issue with credentials.
* Sat Oct 13 2018 antoine.belvire@opensuse.org
- Update to version 0.9.45:
  * Fix a regression in grouping (glgo#World/eolie#316).
- Changes from version 0.9.44:
  * Don't intercept CTRL+RET outside the location bar
    (glgo#World/eolie#315).
- Changes from version 0.9.43:
  * Fix hang.
- Changes from version 0.9.42:
  * Rework favicons code.
* Fri Oct  5 2018 antoine.belvire@opensuse.org
- Update to version 0.9.41:
  * Fix an issue in download popover.
  * Updated translations.
* Sun Sep 30 2018 antoine.belvire@opensuse.org
- Update to version 0.9.40:
  * Fix an issue with adblock (glgo#World/eolie#314).
- Changes from version 0.9.39:
  * Fix a crash.
- Changes from version 0.9.38:
  * Fix favicons.
  * Remove profiles feature until webkit#186338 is fixed.
  * Updated translations.
* Mon Sep 17 2018 antoine.belvire@opensuse.org
- Update to version 0.9.37:
  * Fix a bug making WebkitGTK to segfault.
  * Updated translations.
* Tue Aug 28 2018 antoine.belvire@opensuse.org
- Update to version 0.9.36:
  * Bug fixes.
- Update git repository URL in _service.
* Thu May 24 2018 antoine.belvire@opensuse.org
- Update to version 0.9.35:
  * Fix Ctrl + clic feature.
* Wed May 16 2018 antoine.belvire@opensuse.org
- Update to version 0.9.34:
  * Fix search provider.
- Update to version 0.9.33:
  * Bug fixes.
- Set required minimum version of gtk+ to 3.20.
* Thu May  3 2018 antoine.belvire@opensuse.org
- Update to version 0.9.32:
  * Better favicon handler.
* Thu Apr 26 2018 antoine.belvire@opensuse.org
- Update to version 0.9.31:
  * Fix a crash when closing a website.
- Update to version 0.9.30:
  * Fix webkit crashes.
  * Fix WebView popover.
* Fri Apr 20 2018 antoine.belvire@opensuse.org
- Update to version 0.9.29:
  * Fix an issue with YouTube.
- Update to version 0.9.28:
  * Do not cache snapshots on error.
  * Faster adblock updater.
- Add missing recommended dependency on python3-beautifulsoup4
  (for bookmarks import).
- Disable changelog generation in _service file (too many commits
  listed to be useful).
* Wed Apr 11 2018 antoine.belvire@opensuse.org
- Update to version 0.9.27:
  * Fix a segfault.
- Update to version 0.9.26:
  * Enhance websites sort.
  * Allow keyboard shortcuts in URI popover.
* Wed Mar 28 2018 antoine.belvire@opensuse.org
- Update to version 0.9.25:
  * Another fix for bookmarks import.
* Sun Mar 25 2018 antoine.belvire@opensuse.org
- Update to version 0.9.24:
  * Fix bookmarks import.
  * Rename Mozilla Sync to Firefox Sync.
  * Workaround for bgo#766284.
* Sat Mar 24 2018 antoine.belvire@opensuse.org
- Update to version 0.9.23:
  * Fix a crash.
- Update to version 0.9.22:
  * Fix a crash.
  * Faster search.
- Update to version 0.9.21:
  * Mozilla sync reworked.
  * Adblock fixes.
  * Faster/Smarter search.
- Update to version 0.9.20:
  * Fix Google suggestions.
- Update to version 0.9.19:
  * Enhance adblock support.
  * Enhance JSblock support.
  * Bug fixes.
  * Move appdata to %%{_datadir}/metainfo.
* Mon Jan 22 2018 antoine.belvire@opensuse.org
- Update to version 0.9.18:
  * Bug fixes.
  * Update translations.
* Sun Jan 21 2018 antoine.belvire@opensuse.org
- Add missing requirements:
  * python3-cairo
  * python3-dateutil
  * python3-gobject
* Thu Jan 11 2018 antoine.belvire@opensuse.org
- Update to version 0.9.17:
  * Remove old code.
  * Do not store favicons smaller than ArtSize.FAVICON.
  * Always show current user agent.
  * Fix broken time calculation for downloads.
  * Use shutdown signal instead of listening to GNOME session
    manager.
  * Extend the python path rather than replacing it.
  * Update translations.
* Wed Dec 27 2017 antoine.belvire@opensuse.org
- Update to version 0.9.16:
  * Bug fixes.
  * Update translations.
- Update URL and Source: Project has moved to GNOME's
  infrastructure.
- Use source service to extract git revision (based on tags).
* Wed Dec  6 2017 antoine.belvire@opensuse.org
- Add git as suggested package:
  * It allows Eolie to retrieve more adblock rules.
- Add some recommended packages for Firefox sync feature:
  * python3-PyFxA
  * python3-cryptography
  * python3-pycrypto
  * python3-requests-hawk
* Tue Dec  5 2017 zaitor@opensuse.org
- Update to version 0.9.15:
  * Enhanced JS blocker.
- Changes from version 0.9.14:
  * Bug fixes.
  * Keep TLS exceptions by default.
- Filter out unwanted typelib(unity) Requires, make package
  installable.
- Drop update-desktop-files BuildRequires and stop using
  suse_update_desktop_file macro, no longer needed on current
  openSUSE releases.
- Use autosetup macro.
* Mon Nov 27 2017 antoine.belvire@opensuse.org
- Update to 0.9.13:
  * Bug fixes.
  * New: Assign any site to a particular cookies profile.
* Sun Nov 19 2017 antoine.belvire@opensuse.org
- Update to 0.9.12:
  * Bug fixes.
* Sun Nov  5 2017 antoine.belvire@opensuse.org
- Update to 0.9.11:
  * Allow copying medias/images URI.
- Update to 0.9.10:
  * Enhanced session manager.
  * Enable content management in private mode.
  * Fix URI bar in RTL.
* Tue Oct 31 2017 antoine.belvire@opensuse.org
- Initial package: eolie 0.9.9.
